@@ -7,20 +7,34 @@ from textwrap import indent
 from typing import Literal, Optional, Tuple, Union
 
 from mdutils.tools.TextUtils import TextUtils
-from mkreports.md_proxy import register_md
 
 from .base import MdObj
 from .file import File, relpath_html
-from .settings import Settings
+from .md_proxy import register_md
+from .settings import PageInfo, Settings
 from .text import SpacedText, Text
 
 
 @register_md("Admonition")
 @dataclass
 class Admonition(MdObj):
-    text: Union[Text, MdObj]
-    page_path: Path
-    javascript_path: Path
+    """
+    An admonition to be added to a page. Can also be collapsed. For more
+    details see also the Materials-theme for mkdocs.
+
+    Args:
+        obj (Union[MdObj, Text]): object in the admonition. Markdown object, string
+            or SpacedText.
+        title (Optional[str]): title shown in the admonition. If missing, defaults
+            to 'kind'.
+        kind (Literal[ 'note', 'abstract', 'info', 'tip', 'success', 'question', 'warning', 'failure', 'danger', 'bug', 'example', 'quote', 'code']): The type of
+            admonition to be shown. See also the Materials-theme for mkdocs for
+            more details.
+        collapse (bool): Should the admonition be collapsed?
+        page_info (Optional[PageInfo]): Only needed when 'kind=="code"'.
+    """
+
+    obj: Union[Text, MdObj]
     title: Optional[str] = None
     kind: Literal[
         "note",
@@ -38,12 +52,16 @@ class Admonition(MdObj):
         "code",
     ] = "note"
     collapse: bool = False
+    page_info: Optional[PageInfo] = None
 
     def __post_init__(self):
         if self.kind == "code":
+            assert self.page_info is not None
+            assert self.page_info.javascript_path is not None
+            javascript_path = self.page_info.javascript_path
             # create a css file that creates a 'code' admonition
-            self.css_path = self.javascript_path / "code_admonition.css"
-            self.javascript_path.mkdir(parents=True, exist_ok=True)
+            self.css_path = javascript_path / "code_admonition.css"
+            javascript_path.mkdir(parents=True, exist_ok=True)
             shutil.copy(
                 Path(__file__).parent / "code_admonition.css",
                 self.css_path,
@@ -51,7 +69,9 @@ class Admonition(MdObj):
 
         # if code-admonition, we need to load additional css
         if self.kind == "code":
-            rel_css_path = relpath_html(self.css_path, self.page_path)
+            assert self.page_info is not None
+            assert self.page_info.page_path is not None
+            rel_css_path = relpath_html(self.css_path, self.page_info.page_path)
             page_settings = dict(css=[rel_css_path])
         else:
             page_settings = {}
@@ -65,13 +85,13 @@ class Admonition(MdObj):
             },
             page=page_settings,
         )
-        if isinstance(self.text, MdObj):
-            admon_text = self.text.body
-            back = self.text.back
-            settings = self.text.settings
+        if isinstance(self.obj, MdObj):
+            admon_text = self.obj.body
+            back = self.obj.back
+            settings = self.obj.settings
             settings = cont_settings + settings
         else:
-            admon_text, back, settings = str(self.text), SpacedText(), cont_settings
+            admon_text, back, settings = str(self.obj), SpacedText(), cont_settings
 
         if self.title is None:
             title_md = ""
@@ -88,7 +108,16 @@ class Admonition(MdObj):
 @register_md("Tab")
 @dataclass
 class Tab(MdObj):
-    text: Union[Text, MdObj]
+    """
+    Tab interface
+
+    Args:
+        obj (Union[Text, MdObj]): The object to be shown in the tab. An MdObj,
+            string or SpacedText.
+        title (Optional[str]): Optional title for the tab.
+    """
+
+    obj: Union[Text, MdObj]
     title: Optional[str] = None
 
     def __post_init__(self):
@@ -100,13 +129,13 @@ class Tab(MdObj):
                 ]
             }
         )
-        if isinstance(self.text, MdObj):
-            tab_text = self.text.body
-            back = self.text.back
-            settings = self.text.settings
+        if isinstance(self.obj, MdObj):
+            tab_text = self.obj.body
+            back = self.obj.back
+            settings = self.obj.settings
             settings = tab_settings + settings
         else:
-            tab_text, back, settings = str(self.text), SpacedText(), tab_settings
+            tab_text, back, settings = str(self.obj), SpacedText(), tab_settings
 
         if self.title is not None:
             title_text = html.escape(self.title)
@@ -123,7 +152,19 @@ class Tab(MdObj):
 @register_md("Code")
 @dataclass
 class Code(MdObj):
-    """Wrapper class for code."""
+    """
+    Shows a code-block.
+
+    Args:
+        code (str): The code to be shown as a string.
+        title (Optional[str]): Optional title for the code block.
+        first_line (Optional[int]): Number at the first line.
+        hl_lines (Optional[Tuple[int, int]]): Line-range for highlighting.
+            Is counted relative to 'first_line'.
+        language (Optional[str]): Language for syntax highlighting.
+        dedent (bool): Should the string be de-dented?
+
+    """
 
     code: str
     title: Optional[str] = None
@@ -174,21 +215,36 @@ class CodeFile(File):
 
     def __init__(
         self,
-        path: Path,
-        store_path: Path,
-        report_path: Path,
+        path: Union[Path, str],
+        page_info: PageInfo,
         title: Optional[str] = None,
         hl_lines: Optional[Tuple[int, int]] = None,
         language: Optional[str] = "python",
     ):
         """
-        Move a code-file into the store-dir and reference it in code block.
+        Set up the code-block with file content.
+
+        Args:
+            path (Union[Path, str]): Abolute path or relative to current working dir for the
+                code-file to be included.
+            page_info (PageInfo): PageInfo on the page where the code is to be added.
+            title (Optional[str]): Title of the code-block. If 'None', the path of the
+                code file relative to the project root will be added. If it should be
+                empty, set to empty string.
+            hl_lines (Optional[Tuple[int, int]]): Optional range of lines for highlighting.
+            language (Optional[str]): Language for syntax highlighting.
         """
-        super().__init__(
-            path=path, store_path=store_path, allow_copy=True, use_hash=True
+        assert page_info.project_root is not None
+        assert page_info.report_path is not None
+
+        path = Path(path)
+
+        super().__init__(path=path, page_info=page_info, allow_copy=True, use_hash=True)
+        self.title = (
+            title
+            if title is not None
+            else str(path.relative_to(page_info.project_root))
         )
-        self.report_path = report_path
-        self.title = title
         self.hl_lines = hl_lines
         self.language = language
 
@@ -212,7 +268,7 @@ class CodeFile(File):
         )
         self._body = SpacedText(
             TextUtils.insert_code(
-                f"--8<-- '{self.path.relative_to(self.report_path)}'", annots
+                f"--8<-- '{self.path.relative_to(page_info.report_path)}'", annots
             ),
             (2, 2),
         )
